==> lms-1.8.0rc5.tar.gz: lms/modules/daemoninstancelist.php <==
<?php

/*
 * LMS version 1.8.0rc5 Rosha
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: daemoninstancelist.php,v 1.5.2.1 2005/12/07 08:56:21 alec Exp $
 */

function GetInstanceList($hostid)
{
	global $DB;

	if($hostid)
		$where = 'WHERE hostid = '.$hostid;
		
	return $DB->GetAll('SELECT daemoninstances.id AS id, daemoninstances.name AS name, daemoninstances.description AS description, 
			module, crontab, priority, disabled, hosts.name AS hostname
			FROM daemoninstances LEFT JOIN hosts ON hosts.id = hostid '
			.$where. 
			' ORDER BY hostname, priority, name');
}

$layout['pagetitle'] = trans('Instances List');

$hostid = $_GET['id'];

$instancelist = GetInstanceList($hostid);

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('instancelist', $instancelist);
$SMARTY->assign('hostid', $hostid);
$SMARTY->assign('hosts', $DB->GetAll('SELECT id, name FROM hosts ORDER BY name'));
$SMARTY->display('daemoninstancelist.html');

?>

==> lms-1.10.2.tar.gz: lms/modules/daemoninstancelist.php <==
<?php

/*
 * LMS version 1.10.2 Roham
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: daemoninstancelist.php,v 1.9.2.1 2007/08/17 13:15:22 alec Exp $
 */

function GetInstanceList($hostid)
{
	global $DB;

	$where = $hostid ? 'WHERE hostid = '.$hostid : '';
		
	return $DB->GetAll('SELECT daemoninstances.id AS id, daemoninstances.name AS name, daemoninstances.description AS description, 
			module, crontab, priority, disabled, hosts.name AS hostname
			FROM daemoninstances LEFT JOIN hosts ON hosts.id = hostid '
			.$where. 
			' ORDER BY hostname, priority, name');
}

$layout['pagetitle'] = trans('Instances List');

$hostid = isset($_GET['id']) ? $_GET['id'] : 0;

$instancelist = GetInstanceList($hostid);

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('instancelist', $instancelist);
$SMARTY->assign('hostid', $hostid);
$SMARTY->assign('hosts', $DB->GetAll('SELECT id, name FROM hosts ORDER BY name'));
$SMARTY->display('daemoninstancelist.html');

?>
